==> haskell-iproute-1.7.5-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.5
id: iproute-1.7.5-3lzhMoTjUvmG1vfLIwyjdc
key: iproute-1.7.5-3lzhMoTjUvmG1vfLIwyjdc
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
abi: 96f1138bb84554b8934b8c7f82485ac8
exposed: True
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
                Data.IP.RouteTable.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/iproute-1.7.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/iproute-1.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/iproute-1.7.5
hs-libraries: HSiproute-1.7.5-3lzhMoTjUvmG1vfLIwyjdc
depends:
    base-4.11.1.0 appar-0.1.4-J5mdtVuytVIKFPXD2MXW4E
    byteorder-1.0.4-JGHrMy8StI888DOmmSVbRy containers-0.5.11.0
    network-2.7.0.2-DHEaxB3Qzor483iLxewsye
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             appar-0.1.4-J5mdtVuytVIKFPXD2MXW4E=3afc9ac4ad2929ee3b1b23302da92a6d
             byteorder-1.0.4-JGHrMy8StI888DOmmSVbRy=c533f76a16979913a599bcb0c7cdc2a1
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             network-2.7.0.2-DHEaxB3Qzor483iLxewsye=6aeecf5609d81737c1dbc231763db621
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.6-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.6
id: iproute-1.7.6-FvhuhLxQcgg2N6HgvcPKdT
key: iproute-1.7.6-FvhuhLxQcgg2N6HgvcPKdT
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
abi: 5b4b75eb65cf9581a2f820b764b981aa
exposed: True
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
                Data.IP.RouteTable.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/iproute-1.7.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/iproute-1.7.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/iproute-1.7.6
hs-libraries: HSiproute-1.7.6-FvhuhLxQcgg2N6HgvcPKdT
depends:
    appar-0.1.4-3HqrCaN6XbcISXsPOwRDsf base-4.12.0.0
    byteorder-1.0.4-IVStE0plZAH4UpHo5zwztw containers-0.6.0.1
    network-2.7.0.2-11unSY69gPCAmgeVCL0SxR
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
